PyXperiment is a scientific measurements package designed to control various measurement instruments (both conforming VISA and based on separate approach). PyXperiment is designed to be used with no coding, providing simple and powerful tool for performing multi-axis multi-device sweep measurements with graphical interface. PyXperiment also allows to script more challenging tasks while taking the advantage of the same GUI and instruments support.